@@ -10,8 +10,8 @@ module Nanoc
         DONE = Object.new
 
         contract Nanoc::Core::ItemRep, C::KeywordArgs[is_outdated: C::Bool], C::Func[C::None => C::Any] => C::Any
-        def run(rep, is_outdated:)
-          fiber = fiber_for(rep, is_outdated: is_outdated) { yield }
+        def run(rep, is_outdated:, &block)
+          fiber = fiber_for(rep, is_outdated: is_outdated, &block)
           while fiber.alive?
             res = fiber.resume
 
